# Python payok.io API Client by except
Python payok.io API Client by except 
Doc: https://payok.io/cabinet/documentation/doc_main.php
## Install
```
pip install payok
```
## Example
```
from  payok import payok_api


balance = payok_api.getBalance(
    123,
    'API_KEY'
)
print(balance)
```


## License

MIT

